summaryrefslogtreecommitdiff
path: root/client
diff options
context:
space:
mode:
authorRazvan Becheriu <razvan@isc.org>2022-01-13 20:08:49 +0200
committerRazvan Becheriu <razvan@isc.org>2022-01-19 20:59:15 +0200
commit0c03eaefbbd3f0e22dd5df600c4b707af294890c (patch)
treededbb2a1972262c4872c4f9b02d787d4f60721af /client
parentf853b9c8e53bc31b95b8ced12e492ab94a7ef2ce (diff)
downloadisc-dhcp-0c03eaefbbd3f0e22dd5df600c4b707af294890c.tar.gz
fixed compilation warning190-dhclient-wrong-argument-to-memcpy
Diffstat (limited to 'client')
-rw-r--r--client/dhclient.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/client/dhclient.c b/client/dhclient.c
index a0ff656b..d06efa55 100644
--- a/client/dhclient.c
+++ b/client/dhclient.c
@@ -137,10 +137,10 @@ static void dhclient_ddns_cb_free(dhcp_ddns_cb_t *ddns_cb,
* the description of the command line. The arguments provide
* a way for the caller to request more specific information about
* the error be printed as well. Mostly this will be that some
* comamnd doesn't include its argument.
*
* \param sfmt - The basic string and format for the specific error
* \param sarg - Generally the offending argument from the comamnd line.
*
* \return Nothing
*/
@@ -567,7 +567,7 @@ main(int argc, char **argv) {
} else if (argv[i][0] == '-') {
usage("Unknown command: %s", argv[i]);
} else if (interfaces_requested < 0) {
- usage("No interfaces comamnd -n and "
+ usage("No interfaces command -n and "
" requested interface %s", argv[i]);
} else {
struct interface_info *tmp = NULL;
@@ -3399,12 +3399,12 @@ make_client_options(struct client_state *client, struct client_lease *lease,
hw_idx = 0;
hw_len = client->interface->hw_address.hlen;
}
- memcpy(&client_identifier.buffer->data + 5 - hw_len,
+ memcpy(client_identifier.buffer->data + 5 - hw_len,
client->interface->hw_address.hbuf + hw_idx,
hw_len);
/* Add the default duid */
- memcpy(&client_identifier.buffer->data+(1+4),
+ memcpy(client_identifier.buffer->data + (1 + 4),
default_duid.data, default_duid.len);
/* And save the option */
@@ -137,10 +137,10 @@ static void dhclient_ddns_cb_free(dhcp_ddns_cb_t *ddns_cb,
* a way for the caller to request more specific information about
* the error be printed as well. Mostly this will be that some
- * comamnd doesn't include its argument.
+ * command doesn't include its argument.
*
* \param sfmt - The basic string and format for the specific error
@@ -137,10 +137,10 @@ static void dhclient_ddns_cb_free(dhcp_ddns_cb_t *ddns_cb,
*
* \param sfmt - The basic string and format for the specific error
- * \param sarg - Generally the offending argument from the comamnd line.
+ * \param sarg - Generally the offending argument from the command line.
*
* \return Nothing